@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from Screens.Screen import Screen
 from Components.Button import Button
 from Components.ActionMap import HelpableActionMap, ActionMap, NumberActionMap
@@ -579,6 +578,8 @@ class MovieSelection(Screen, HelpableScreen, SelectionEventInfo, InfoBarBase, Pr
 		self["key_green"] = StaticText("")
 		self["key_yellow"] = StaticText("")
 		self["key_blue"] = StaticText("")
+		self["key_menu"] = StaticText(_("MENU"))
+		self["key_info"] = StaticText(_("INFO"))
 		self["movie_off"] = MultiPixmap()
 		self["movie_off"].hide()
 		self["movie_sort"] = MultiPixmap()
@@ -1390,9 +1391,10 @@ class MovieSelection(Screen, HelpableScreen, SelectionEventInfo, InfoBarBase, Pr
 		self.updateTags()
 		title = _("Recorded files...")
 		if config.usage.setup_level.index >= 2: # expert+
-			title += "  •  " + config.movielist.last_videodir.value
+			title += "  " + config.movielist.last_videodir.value
 		if self.selected_tags:
 			title += " - " + ','.join(self.selected_tags)
+		self.setTitle(title)
 		
 		self.displayMovieOffStatus()
 		self.displaySortStatus()
@@ -1400,8 +1402,6 @@ class MovieSelection(Screen, HelpableScreen, SelectionEventInfo, InfoBarBase, Pr
 			if self.reload_home:
 				self["list"].moveToFirstMovie()
 		self["freeDiskSpace"].update()
-		title += "  •  " + self.diskinfo.getText()
-		self.setTitle(title)
 		self["waitingtext"].visible = False
 		self.createPlaylist()
 		if self.playGoTo:
